@@ -1,4 +1,4 @@
-/* $Id: third.c,v 1.7 1999/02/23 11:42:46 martin Exp $ */
+/* $Id: third.c,v 1.9 2003/10/19 16:54:17 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -38,8 +38,8 @@ int
 main (int argc, char *argv[])
 {
 	setlocale (LC_ALL, "");
-	bindtextdomain (PACKAGE, GTOPLOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
+	textdomain (GETTEXT_PACKAGE);
 
 	gh_enter (argc, argv, main_prog);
 	exit (0);
