@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: swap.h,v 1.21 2003/10/19 16:10:17 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -43,12 +41,12 @@ typedef struct _glibtop_swap	glibtop_swap;
 
 struct _glibtop_swap
 {
-    u_int64_t	flags,
-	total,		/* GLIBTOP_SWAP_TOTAL	*/
-	used,		/* GLIBTOP_SWAP_USED	*/
-	free,		/* GLIBTOP_SWAP_FREE	*/
-	pagein,		/* GLIBTOP_SWAP_PAGEIN	*/
-	pageout;	/* GLIBTOP_SWAP_PAGEOUT	*/
+	u_int64_t	flags,
+		total,		/* GLIBTOP_SWAP_TOTAL	*/
+		used,		/* GLIBTOP_SWAP_USED	*/
+		free,		/* GLIBTOP_SWAP_FREE	*/
+		pagein,		/* GLIBTOP_SWAP_PAGEIN	*/
+		pageout;	/* GLIBTOP_SWAP_PAGEOUT	*/
 };
 
 #define glibtop_get_swap(swap)	glibtop_get_swap_l(glibtop_global_server, swap)
@@ -59,14 +57,14 @@ struct _glibtop_swap
 #define glibtop_get_swap_r		glibtop_get_swap_s
 #endif
 
-int glibtop_get_swap_l (glibtop *server, glibtop_swap *buf);
+void glibtop_get_swap_l (glibtop *server, glibtop_swap *buf);
 
 #if GLIBTOP_SUID_SWAP
-int glibtop_init_swap_p (glibtop *server);
-int glibtop_get_swap_p (glibtop *server, glibtop_swap *buf);
+void glibtop_init_swap_p (glibtop *server);
+void glibtop_get_swap_p (glibtop *server, glibtop_swap *buf);
 #else
-int glibtop_init_swap_s (glibtop *server);
-int glibtop_get_swap_s (glibtop *server, glibtop_swap *buf);
+void glibtop_init_swap_s (glibtop *server);
+void glibtop_get_swap_s (glibtop *server, glibtop_swap *buf);
 #endif
 
 #ifdef GLIBTOP_NAMES
