@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: mem.c,v 1.21.2.1 2003/10/20 20:41:06 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -35,59 +33,45 @@ static const unsigned long _glibtop_sysdeps_mem =
 
 /* Init function. */
 
-int
+void
 glibtop_init_mem_s (glibtop *server)
 {
-    server->sysdeps.mem = _glibtop_sysdeps_mem;
-
-    return 0;
+	server->sysdeps.mem = _glibtop_sysdeps_mem;
 }
 
 /* Provides information about memory usage. */
 
 #define FILENAME	"/proc/meminfo"
 
-int
+void
 glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 {
-    char buffer [BUFSIZ], *p;
-    int fd, len;
+	char buffer [BUFSIZ], *p;
+	int fd, len;
 
-    glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
+	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
 
-    memset (buf, 0, sizeof (glibtop_mem));
+	memset (buf, 0, sizeof (glibtop_mem));
 
-    fd = open (FILENAME, O_RDONLY);
-    if (fd < 0) {
-	glibtop_warn_io_r (server, "open (%s)", FILENAME);
-	return -1;
-		
-    }
+	fd = open (FILENAME, O_RDONLY);
+	if (fd < 0)
+		glibtop_error_io_r (server, "open (%s)", FILENAME);
+
+	len = read (fd, buffer, BUFSIZ-1);
+	if (len < 0)
+		glibtop_error_io_r (server, "read (%s)", FILENAME);
 
-    len = read (fd, buffer, BUFSIZ-1);
-    if (len < 0) {
 	close (fd);
-	glibtop_warn_io_r (server, "read (%s)", FILENAME);
-	return -1;
-    }
 
-    close (fd);
+	buffer [len] = '\0';
 
-    buffer [len] = '\0';
+	buf->total  = get_scaled(buffer, "MemTotal:");
+	buf->used   = get_scaled(buffer, "Active:");
+	buf->free   = get_scaled(buffer, "MemFree:");
+	buf->shared = get_scaled(buffer, "Mapped:");
+	buf->buffer = get_scaled(buffer, "Buffers:");
+	buf->cached = get_scaled(buffer, "Cached:");
 
-    p = skip_line (buffer);
-    p = skip_token (p);		/* "Mem:" */
-
-    buf->total  = strtoul (p, &p, 0);
-    buf->used   = strtoul (p, &p, 0);
-    buf->free   = strtoul (p, &p, 0);
-    buf->shared = strtoul (p, &p, 0);
-    buf->buffer = strtoul (p, &p, 0);
-    buf->cached = strtoul (p, &p, 0);
-
-    buf->user = buf->total - buf->free - buf->shared - buf->buffer;
-
-    buf->flags = _glibtop_sysdeps_mem;
-
-    return 0;
+ 	buf->user = buf->total - buf->free - buf->cached - buf->buffer;
+ 	buf->flags = _glibtop_sysdeps_mem;
 }
