@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: proclist.c,v 1.9 2003/10/19 16:10:39 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,14 +19,30 @@
    along with LibGTop; see the file COPYING. If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
- */
+*/
 
 #include <glibtop/proclist.h>
 
-const char *glibtop_names_proclist[] = { };
+const char *glibtop_names_proclist [GLIBTOP_MAX_PROCLIST] =
+{
+	"number", "total", "size"
+};
 
-const unsigned glibtop_types_proclist[] = { };
+const unsigned glibtop_types_proclist [GLIBTOP_MAX_PROCLIST] =
+{
+	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG
+};
 
-const char *glibtop_labels_proclist[] = { };
+const char *glibtop_labels_proclist [GLIBTOP_MAX_PROCLIST] =
+{
+	N_("Number of list elements"),
+	N_("Total size of list"),
+	N_("Size of a single list element")
+};
 
-const char *glibtop_descriptions_proclist[] = { };
+const char *glibtop_descriptions_proclist [GLIBTOP_MAX_PROCLIST] =
+{
+	N_("Number of list elements"),
+	N_("Total size of list"),
+	N_("Size of a single list element")
+};
