@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procargs.c,v 1.12 2003/10/19 16:55:49 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -32,12 +30,10 @@ static const unsigned long _glibtop_sysdeps_proc_args = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_args_s (glibtop *server)
 {
-    server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
-
-    return 0;
+	server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
 }
 
 /* Provides detailed information about a process. */
@@ -46,6 +42,6 @@ char *
 glibtop_get_proc_args_s (glibtop *server, glibtop_proc_args *buf,
 			 pid_t pid, unsigned max_len)
 {
-    memset (buf, 0, sizeof (glibtop_proc_args));
-    return NULL;
+	memset (buf, 0, sizeof (glibtop_proc_args));
+	return NULL;
 }
